
/* Generated data (by glib-mkenums) */

#ifndef MOO_UTILS_ENUMS_H
#define MOO_UTILS_ENUMS_H

#include <glib-object.h>

G_BEGIN_DECLS
/* MooSaveChangesResponse */
GType moo_save_changes_response_get_type (void) G_GNUC_CONST;
#define MOO_TYPE_SAVE_CHANGES_RESPONSE (moo_save_changes_response_get_type ())
/* MooFileDialogType */
GType moo_file_dialog_type_get_type (void) G_GNUC_CONST;
#define MOO_TYPE_FILE_DIALOG_TYPE (moo_file_dialog_type_get_type ())
/* MooUiNodeType */
GType moo_ui_node_type_get_type (void) G_GNUC_CONST;
#define MOO_TYPE_UI_NODE_TYPE (moo_ui_node_type_get_type ())
/* MooUiNodeFlags */
GType moo_ui_node_flags_get_type (void) G_GNUC_CONST;
#define MOO_TYPE_UI_NODE_FLAGS (moo_ui_node_flags_get_type ())
/* MooUiWidgetType */
GType moo_ui_widget_type_get_type (void) G_GNUC_CONST;
#define MOO_TYPE_UI_WIDGET_TYPE (moo_ui_widget_type_get_type ())
/* MooCloseResponse */
GType moo_close_response_get_type (void) G_GNUC_CONST;
#define MOO_TYPE_CLOSE_RESPONSE (moo_close_response_get_type ())

G_END_DECLS

#endif /* MOO_UTILS_ENUMS_H */

/* Generated data ends here */

